==> cscec5b-wzxt-api-3.0.0-20201109.031654-39-sources.jar: com/ejianc/business/wzxt/vo/CheckRestVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 对外接口验收实体
 *
 * @author generator
 *
 */
public class CheckRestVO {
    private static final long serialVersionUID = 1L;

    private Long id; // 主键ID
    private String billCode; // 单据编号
    private String projectSourceId; // 项目来源id
    private String projectInstoreId; // 项目仓库
    private String projectInstoreName; // 项目仓库名称
    private String contractId; // 合同主键
    private String contractName; // 合同名称
    private Long supplierId; // 设备供应商
    private String supplierName; // 供应商名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date checkDate; // 验收日期
    private Long employeeId; // 验收人
    private String employeeName; // 验收人名称
    private String checkAddress; // 验收地点
    private String checkType; // 业务类型
    private String isRequirement; // 是否满足质量要求0-是，1-否
    private String isStandard; // 是否满足合同要求0-是，1-否
    private Integer billState; // 单据状态（审批必须字段）
    private String licensePlate; // 车牌号
    private Integer useState; // 引用状态（0-未引用，1-已引用）

    // 验收明细子表
    private List<CheckDetailRestVO> detailList = new ArrayList<>();

    public List<CheckDetailRestVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<CheckDetailRestVO> detailList) {
        this.detailList = detailList;
    }

    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目仓库
     */
    public String getProjectInstoreId() {
        return projectInstoreId;
    }

    /**
     * 项目仓库
     */
    public void setProjectInstoreId(String projectInstoreId) {
        this.projectInstoreId = projectInstoreId;
    }

    /**
     * 项目仓库名称
     */
    public String getProjectInstoreName() {
        return projectInstoreName;
    }

    /**
     * 项目仓库名称
     */
    public void setProjectInstoreName(String projectInstoreName) {
        this.projectInstoreName = projectInstoreName;
    }
    /**
     * 合同主键
     */
    public String getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 设备供应商
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    @ReferDeserialTransfer
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 验收日期
     */
    public java.util.Date getCheckDate() {
        return checkDate;
    }

    /**
     * 验收日期
     */
    public void setCheckDate(java.util.Date checkDate) {
        this.checkDate = checkDate;
    }
    /**
     * 验收人
     */
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 验收人
     */
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 验收人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 验收人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 验收地点
     */
    public String getCheckAddress() {
        return checkAddress;
    }

    /**
     * 验收地点
     */
    public void setCheckAddress(String checkAddress) {
        this.checkAddress = checkAddress;
    }
    /**
     * 业务类型
     */
    public String getCheckType() {
        return checkType;
    }

    /**
     * 业务类型
     */
    public void setCheckType(String checkType) {
        this.checkType = checkType;
    }
    /**
     * 是否满足质量要求0-是，1-否
     */
    public String getIsRequirement() {
        return isRequirement;
    }

    /**
     * 是否满足质量要求0-是，1-否
     */
    public void setIsRequirement(String isRequirement) {
        this.isRequirement = isRequirement;
    }
    /**
     * 是否满足合同要求0-是，1-否
     */
    public String getIsStandard() {
        return isStandard;
    }

    /**
     * 是否满足合同要求0-是，1-否
     */
    public void setIsStandard(String isStandard) {
        this.isStandard = isStandard;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 车牌号
     */
    public String getLicensePlate() {
        return licensePlate;
    }

    /**
     * 车牌号
     */
    public void setLicensePlate(String licensePlate) {
        this.licensePlate = licensePlate;
    }
    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public Integer getUseState() {
        return useState;
    }

    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public void setUseState(Integer useState) {
        this.useState = useState;
    }

}

==> cscec5b-wzxt-api-3.0.0-20201204.093433-99-sources.jar: com/ejianc/business/wzxt/vo/CheckRestVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 对外接口验收实体
 *
 * @author generator
 *
 */
public class CheckRestVO {
    private static final long serialVersionUID = 1L;

    private Long id; // 主键ID
    private String billCode; // 单据编号
    private String projectSourceId; // 项目来源id
    private String projectInstoreId; // 项目仓库
    private String projectInstoreName; // 项目仓库名称
    private String contractId; // 合同主键
    private String contractName; // 合同名称
    private Long supplierId; // 设备供应商
    private String supplierName; // 供应商名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date checkDate; // 验收日期
    private Long employeeId; // 验收人
    private String employeeName; // 验收人名称
    private String checkAddress; // 验收地点
    private String checkType; // 业务类型
    private String isRequirement; // 是否满足质量要求0-否，1-是
    private String isStandard; // 是否满足合同要求0-否，1-是
    private Integer billState; // 单据状态（审批必须字段）
    private String licensePlate; // 车牌号
    private Integer useState; // 引用状态（0-未引用，1-已引用）

    // 验收明细子表
    private List<CheckDetailRestVO> detailList = new ArrayList<>();

    public List<CheckDetailRestVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<CheckDetailRestVO> detailList) {
        this.detailList = detailList;
    }

    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    /**
     * 单据编号
     */
    public String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目仓库
     */
    public String getProjectInstoreId() {
        return projectInstoreId;
    }

    /**
     * 项目仓库
     */
    public void setProjectInstoreId(String projectInstoreId) {
        this.projectInstoreId = projectInstoreId;
    }

    /**
     * 项目仓库名称
     */
    public String getProjectInstoreName() {
        return projectInstoreName;
    }

    /**
     * 项目仓库名称
     */
    public void setProjectInstoreName(String projectInstoreName) {
        this.projectInstoreName = projectInstoreName;
    }
    /**
     * 合同主键
     */
    public String getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    public void setContractId(String contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 设备供应商
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    @ReferDeserialTransfer
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 验收日期
     */
    public java.util.Date getCheckDate() {
        return checkDate;
    }

    /**
     * 验收日期
     */
    public void setCheckDate(java.util.Date checkDate) {
        this.checkDate = checkDate;
    }
    /**
     * 验收人
     */
    public Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 验收人
     */
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 验收人名称
     */
    public String getEmployeeName() {
        return employeeName;
    }

    /**
     * 验收人名称
     */
    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 验收地点
     */
    public String getCheckAddress() {
        return checkAddress;
    }

    /**
     * 验收地点
     */
    public void setCheckAddress(String checkAddress) {
        this.checkAddress = checkAddress;
    }
    /**
     * 业务类型
     */
    public String getCheckType() {
        return checkType;
    }

    /**
     * 业务类型
     */
    public void setCheckType(String checkType) {
        this.checkType = checkType;
    }
    /**
     * 是否满足质量要求0-否，1-是
     */
    public String getIsRequirement() {
        return isRequirement;
    }

    /**
     * 是否满足质量要求0-否，1-是
     */
    public void setIsRequirement(String isRequirement) {
        this.isRequirement = isRequirement;
    }
    /**
     * 是否满足合同要求0-是，1-否
     */
    public String getIsStandard() {
        return isStandard;
    }

    /**
     * 是否满足合同要求0-是，1-否
     */
    public void setIsStandard(String isStandard) {
        this.isStandard = isStandard;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 车牌号
     */
    public String getLicensePlate() {
        return licensePlate;
    }

    /**
     * 车牌号
     */
    public void setLicensePlate(String licensePlate) {
        this.licensePlate = licensePlate;
    }
    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public Integer getUseState() {
        return useState;
    }

    /**
     * 引用状态（0-未引用，1-已引用）
     */
    public void setUseState(Integer useState) {
        this.useState = useState;
    }

}
